@@ -1,12 +1,15 @@
 package Org::Element::Block;
 
+our $DATE = '2016-12-24'; # DATE
+our $VERSION = '0.53'; # VERSION
+
 use 5.010;
 use locale;
 use Moo;
 use experimental 'smartmatch';
 extends 'Org::Element';
-
-our $VERSION = '0.52'; # VERSION
+with 'Org::Element::Role';
+with 'Org::Element::BlockRole';
 
 has name => (is => 'rw');
 has args => (is => 'rw');
@@ -54,12 +57,14 @@ Org::Element::Block - Represent Org block
 
 =head1 VERSION
 
-This document describes version 0.52 of Org::Element::Block (from Perl distribution Org-Parser), released on 2016-11-06.
+This document describes version 0.53 of Org::Element::Block (from Perl distribution Org-Parser), released on 2016-12-24.
 
 =head1 DESCRIPTION
 
 Derived from L<Org::Element>.
 
+=for Pod::Coverage element_as_string BUILD
+
 =head1 ATTRIBUTES
 
 =head2 name => STR
@@ -80,8 +85,6 @@ Indentation on end line (before C<#+END>), or empty string if none.
 
 =head1 METHODS
 
-=for Pod::Coverage element_as_string BUILD
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser>.
