@@ -1,11 +1,14 @@
 package Org::Element::Comment;
 
+our $DATE = '2016-12-24'; # DATE
+our $VERSION = '0.53'; # VERSION
+
 use 5.010;
 use locale;
 use Moo;
 extends 'Org::Element';
-
-our $VERSION = '0.52'; # VERSION
+with 'Org::Element::Role';
+with 'Org::Element::BlockRole';
 
 1;
 # ABSTRACT: Represent Org comment
@@ -22,7 +25,7 @@ Org::Element::Comment - Represent Org comment
 
 =head1 VERSION
 
-This document describes version 0.52 of Org::Element::Comment (from Perl distribution Org-Parser), released on 2016-11-06.
+This document describes version 0.53 of Org::Element::Comment (from Perl distribution Org-Parser), released on 2016-12-24.
 
 =head1 DESCRIPTION
 
