@@ -1,12 +1,15 @@
 package Org::Element::Drawer;
 
+our $DATE = '2016-12-24'; # DATE
+our $VERSION = '0.53'; # VERSION
+
 use 5.010;
 use locale;
 use Moo;
 use experimental 'smartmatch';
 extends 'Org::Element';
-
-our $VERSION = '0.52'; # VERSION
+with 'Org::Element::Role';
+with 'Org::Element::BlockRole';
 
 has name => (is => 'rw');
 has properties => (is => 'rw');
@@ -55,12 +58,14 @@ Org::Element::Drawer - Represent Org drawer
 
 =head1 VERSION
 
-This document describes version 0.52 of Org::Element::Drawer (from Perl distribution Org-Parser), released on 2016-11-06.
+This document describes version 0.53 of Org::Element::Drawer (from Perl distribution Org-Parser), released on 2016-12-24.
 
 =head1 DESCRIPTION
 
 Derived from L<Org::Element>.
 
+=for Pod::Coverage BUILD as_string
+
 =head1 ATTRIBUTES
 
 =head2 name => STR
@@ -73,8 +78,6 @@ Collected properties in the drawer.
 
 =head1 METHODS
 
-=for Pod::Coverage BUILD as_string
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Org-Parser>.
