@@ -1,11 +1,14 @@
 package Org::Element::FixedWidthSection;
 
+our $DATE = '2016-12-24'; # DATE
+our $VERSION = '0.53'; # VERSION
+
 use 5.010;
 use locale;
 use Moo;
 extends 'Org::Element';
-
-our $VERSION = '0.52'; # VERSION
+with 'Org::Element::Role';
+with 'Org::Element::BlockRole';
 
 sub text {
     my ($self) = @_;
@@ -29,7 +32,7 @@ Org::Element::FixedWidthSection - Represent Org fixed-width section
 
 =head1 VERSION
 
-This document describes version 0.52 of Org::Element::FixedWidthSection (from Perl distribution Org-Parser), released on 2016-11-06.
+This document describes version 0.53 of Org::Element::FixedWidthSection (from Perl distribution Org-Parser), released on 2016-12-24.
 
 =head1 SYNOPSIS
 
