@@ -1,7 +1,7 @@
 package Org::Element::Headline;
 
-our $DATE = '2016-11-06'; # DATE
-our $VERSION = '0.52'; # VERSION
+our $DATE = '2016-12-24'; # DATE
+our $VERSION = '0.53'; # VERSION
 
 use 5.010;
 use locale;
@@ -9,6 +9,8 @@ use Log::Any::IfLOG '$log';
 use Moo;
 use experimental 'smartmatch';
 extends 'Org::Element';
+with 'Org::Element::Role';
+with 'Org::Element::BlockRole';
 
 has level => (is => 'rw');
 has title => (is => 'rw');
@@ -300,13 +302,13 @@ Org::Element::Headline - Represent Org headline
 
 =head1 VERSION
 
-This document describes version 0.52 of Org::Element::Headline (from Perl distribution Org-Parser), released on 2016-11-06.
+This document describes version 0.53 of Org::Element::Headline (from Perl distribution Org-Parser), released on 2016-12-24.
 
 =head1 DESCRIPTION
 
 Derived from L<Org::Element>.
 
-=for Pod::Coverage ^(todo_priority)$
+=for Pod::Coverage ^(header_as_string|as_string|todo_priority)$
 
 =head1 ATTRIBUTES
 
@@ -346,8 +348,6 @@ statistics cookie.
 
 =head1 METHODS
 
-=for Pod::Coverage header_as_string as_string
-
 =head2 $el->get_tags() => ARRAY
 
 Get tags for this headline. A headline can define tags or inherit tags from its
