@@ -1,13 +1,15 @@
 package Org::Element::Setting;
 
-our $DATE = '2016-11-06'; # DATE
-our $VERSION = '0.52'; # VERSION
+our $DATE = '2016-12-24'; # DATE
+our $VERSION = '0.53'; # VERSION
 
 use 5.010001;
 use locale;
 use Moo;
 use experimental 'smartmatch';
 extends 'Org::Element';
+with 'Org::Element::Role';
+with 'Org::Element::BlockRole';
 
 our @known_settings = qw(
 ARCHIVE
@@ -101,6 +103,7 @@ has name => (is => 'rw');
 has args => (is => 'rw');
 has indent => (is => 'rw');
 
+# static method
 sub indentable_settings {
     state $data = [qw/TBLFM/];
     $data;
@@ -189,12 +192,14 @@ Org::Element::Setting - Represent Org in-buffer settings
 
 =head1 VERSION
 
-This document describes version 0.52 of Org::Element::Setting (from Perl distribution Org-Parser), released on 2016-11-06.
+This document describes version 0.53 of Org::Element::Setting (from Perl distribution Org-Parser), released on 2016-12-24.
 
 =head1 DESCRIPTION
 
 Derived from L<Org::Element>.
 
+=for Pod::Coverage as_string BUILD
+
 =head1 ATTRIBUTES
 
 =head2 name => STR
@@ -211,8 +216,6 @@ Indentation (whitespaces before C<#+>), or empty string if none.
 
 =head1 METHODS
 
-=for Pod::Coverage as_string BUILD
-
 =head2 Org::Element::Setting->indentable_settings -> ARRAY
 
 Return an arrayref containing the setting names that can be indented. In Org,
