@@ -1,13 +1,15 @@
 package Org::Element::Table;
 
-our $DATE = '2016-11-06'; # DATE
-our $VERSION = '0.52'; # VERSION
+our $DATE = '2016-12-24'; # DATE
+our $VERSION = '0.53'; # VERSION
 
 use 5.010;
 use locale;
 use Log::Any::IfLOG '$log';
 use Moo;
 extends 'Org::Element';
+with 'Org::Element::Role';
+with 'Org::Element::BlockRole';
 
 has _dummy => (is => 'rw'); # workaround Moo bug
 
@@ -121,19 +123,19 @@ Org::Element::Table - Represent Org table
 
 =head1 VERSION
 
-This document describes version 0.52 of Org::Element::Table (from Perl distribution Org-Parser), released on 2016-11-06.
+This document describes version 0.53 of Org::Element::Table (from Perl distribution Org-Parser), released on 2016-12-24.
 
 =head1 DESCRIPTION
 
 Derived from L<Org::Element>. Must have L<Org::Element::TableRow> or
 L<Org::Element::TableVLine> instances as its children.
 
+=for Pod::Coverage BUILD
+
 =head1 ATTRIBUTES
 
 =head1 METHODS
 
-=for Pod::Coverage BUILD
-
 =head2 $table->rows() => ELEMENTS
 
 Return the rows of the table.
